require "import"

import "android.widget.*"
import "android.view.*"
import "android.app.*"
import "android.content.*"
import "android.net.*"
import "android.os.*"
import "android.text.format.Formatter"
import "java.io.File"
import "android.provider.Settings"

local activity = activity
local deviceInfoTextView, batteryInfoTextView, dateTimeTextView, networkTypeTextView, networkOperatorTextView, cpuUsageTextView, timeZoneTextView, storageInfoTextView, ramUsageTextView, appCountTextView, deviceTemperatureTextView

function onCreate(savedInstanceState)
    activity.setTitle("معلومات عن الجهاز")
    local layout = LinearLayout(activity)
    layout.setOrientation(1)

    deviceInfoTextView = TextView(activity)
    deviceInfoTextView.setTextSize(16)
    layout.addView(deviceInfoTextView)

    batteryInfoTextView = TextView(activity)
    batteryInfoTextView.setTextSize(16)
    layout.addView(batteryInfoTextView)

    dateTimeTextView = TextView(activity)
    dateTimeTextView.setTextSize(16)
    layout.addView(dateTimeTextView)

    networkTypeTextView = TextView(activity)
    networkTypeTextView.setTextSize(16)
    layout.addView(networkTypeTextView)

    networkOperatorTextView = TextView(activity)
    networkOperatorTextView.setTextSize(16)
    layout.addView(networkOperatorTextView)

    cpuUsageTextView = TextView(activity)
    cpuUsageTextView.setTextSize(16)
    layout.addView(cpuUsageTextView)

    timeZoneTextView = TextView(activity)
    timeZoneTextView.setTextSize(16)
    layout.addView(timeZoneTextView)

    storageInfoTextView = TextView(activity)
    storageInfoTextView.setTextSize(16)
    layout.addView(storageInfoTextView)

    ramUsageTextView = TextView(activity)
    ramUsageTextView.setTextSize(16)
    layout.addView(ramUsageTextView)

    appCountTextView = TextView(activity)
    appCountTextView.setTextSize(16)
    layout.addView(appCountTextView)

    -- إضافة TextView جديد لعرض درجة حرارة الجهاز
    deviceTemperatureTextView = TextView(activity)
    deviceTemperatureTextView.setTextSize(16)
    layout.addView(deviceTemperatureTextView)

    local button = Button(activity)
    button.setText("عرض المعلومات")
    button.setOnClickListener{
        onClick = function(v)
            checkDeviceInfo()
            checkBatteryInfo()
            checkDateAndTime()
            checkNetworkType()
            checkNetworkOperator()
            checkCPUUsage()
            checkTimeZone()
            checkStorageInfo()
            checkRamUsage()
            checkAppCount()
            checkDeviceTemperature()  -- إضافة استدعاء الدالة الجديدة هنا
        end
    }
    layout.addView(button)

    local settingsButton = Button(activity)
    settingsButton.setText("فتح الإعدادات")
    settingsButton.setOnClickListener{
        onClick = function(v)
            openSettings()
        end
    }
    layout.addView(settingsButton)

    local fileManagerButton = Button(activity)
    fileManagerButton.setText("فتح مدير الملفات")
    fileManagerButton.setOnClickListener{
        onClick = function(v)
            openFileManager()
        end
    }
    layout.addView(fileManagerButton)

    activity.setContentView(layout)
end

function checkDeviceInfo()
    local deviceInfo = string.format("الجهاز: %s\nالموديل: %s\nإصدار النظام: %s", Build.MANUFACTURER, Build.MODEL, Build.VERSION.RELEASE)
    deviceInfoTextView.setText(deviceInfo)
end

function checkBatteryInfo()
    local intentFilter = IntentFilter(Intent.ACTION_BATTERY_CHANGED)
    local batteryStatus = activity.registerReceiver(nil, intentFilter)
    local level = batteryStatus.getIntExtra(BatteryManager.EXTRA_LEVEL, -1)
    local scale = batteryStatus.getIntExtra(BatteryManager.EXTRA_SCALE, -1)
    local batteryPct = level / scale * 100
    local batteryInfo = string.format("البطارية: %.2f%%", batteryPct)
    batteryInfoTextView.setText(batteryInfo)

    local temperature = batteryStatus.getIntExtra(BatteryManager.EXTRA_TEMPERATURE, 0)
    local temperatureCelsius = temperature / 10
    batteryInfoTextView.append("\nدرجة حرارة البطارية: " .. temperatureCelsius .. " °C")

    local voltage = batteryStatus.getIntExtra(BatteryManager.EXTRA_VOLTAGE, 0)
    local voltageValue = voltage / 1000.0
    batteryInfoTextView.append("\nجهد البطارية: " .. voltageValue .. " V")

    local status = batteryStatus.getIntExtra(BatteryManager.EXTRA_STATUS, -1)
    local isCharging = status == BatteryManager.BATTERY_STATUS_CHARGING or status == BatteryManager.BATTERY_STATUS_FULL
    local chargingStatus = isCharging and "موصل بالشاحن" or "غير موصل بالشاحن"
    batteryInfoTextView.append("\nحالة الشاحن: " .. chargingStatus)
end

function checkDateAndTime()
    local calendar = Calendar.getInstance()
    local dateTime = string.format("التاريخ: %02d-%02d-%04d\nالوقت: %02d:%02d:%02d", calendar.get(Calendar.MONTH) + 1, calendar.get(Calendar.DAY_OF_MONTH), calendar.get(Calendar.YEAR), calendar.get(Calendar.HOUR_OF_DAY), calendar.get(Calendar.MINUTE), calendar.get(Calendar.SECOND))
    dateTimeTextView.setText(dateTime)
end

function checkNetworkType()
    local connectivityManager = activity.getSystemService(Context.CONNECTIVITY_SERVICE)
    local networkInfo = connectivityManager.getActiveNetworkInfo()
    if networkInfo then
        local networkType = networkInfo.getTypeName()
        networkTypeTextView.setText("نوع الشبكة: " .. networkType)
    else
        networkTypeTextView.setText("نوع الشبكة: غير معروف")
    end
end

function checkNetworkOperator()
    local telephonyManager = activity.getSystemService(Context.TELEPHONY_SERVICE)
    local networkOperator = telephonyManager.getNetworkOperatorName()
    networkOperatorTextView.setText("مشغل الشبكة: " .. networkOperator)
end

function checkCPUUsage()
    local activityManager = activity.getSystemService(Context.ACTIVITY_SERVICE)
    local memoryInfo = ActivityManager.MemoryInfo()
    activityManager.getMemoryInfo(memoryInfo)
    local cpuUsage = string.format("استخدام المعالج (cpu): %.2f%%", 100 - memoryInfo.availMem / memoryInfo.totalMem * 100)
    cpuUsageTextView.setText(cpuUsage)
end

function checkTimeZone()
    local timeZone = TimeZone.getDefault()
    local timeZoneInfo = string.format("المنطقة الزمنية: %s", timeZone.getDisplayName())
    timeZoneTextView.setText(timeZoneInfo)
end

function checkStorageInfo()
    local stat = StatFs(Environment.getExternalStorageDirectory().getPath())
    local blockSize = stat.getBlockSizeLong()
    local totalBlocks = stat.getBlockCountLong()
    local availableBlocks = stat.getAvailableBlocksLong()
    local totalSize = totalBlocks * blockSize
    local availableSize = availableBlocks * blockSize
    local storageInfo = string.format("التخزين: %s / %s", Formatter.formatFileSize(activity, totalSize), Formatter.formatFileSize(activity, availableSize))
    storageInfoTextView.setText(storageInfo)
end

function checkRamUsage()
    local activityManager = activity.getSystemService(Context.ACTIVITY_SERVICE)
    local memoryInfo = ActivityManager.MemoryInfo()
    activityManager.getMemoryInfo(memoryInfo)
    local totalRam = memoryInfo.totalMem
    local availableRam = memoryInfo.availMem
    local usedRam = totalRam - availableRam
    local ramUsage = string.format("استخدام الذاكرة العشوائية (ram): %s / %s", Formatter.formatFileSize(activity, usedRam), Formatter.formatFileSize(activity, totalRam))
    ramUsageTextView.setText(ramUsage)
end

function checkAppCount()
    local packageManager = activity.getPackageManager()
    local packages = packageManager.getInstalledPackages(0)
    local appCount = #packages
    appCountTextView.setText("عدد التطبيقات المثبتة: " .. appCount)
end

function checkDeviceTemperature()
    local temperatureFile = io.open("/sys/class/thermal/thermal_zone0/temp", "r")
    if temperatureFile then
        local temp = temperatureFile:read("*n") / 1000
        temperatureFile:close()
        local temperatureInfo = string.format("درجة حرارة الجهاز: %.2f °C", temp)
        deviceTemperatureTextView.setText(temperatureInfo)
    else
        deviceTemperatureTextView.setText("غير قادر على قراءة درجة حرارة الجهاز")
    end
end

function openSettings()
    local intent = Intent(Settings.ACTION_SETTINGS)
    activity.startActivity(intent)
end

function openFileManager()
    local intent = Intent(Intent.ACTION_VIEW)
    intent.setDataAndType(Uri.parse("content://com.android.externalstorage.documents/root/primary"), "vnd.android.document/directory")
    if intent.resolveActivity(activity.getPackageManager()) then
        activity.startActivity(intent)
    else
        Toast.makeText(activity, "لا يوجد تطبيق مدير ملفات متاح", Toast.LENGTH_SHORT).show()
    end
end